tfe_tensor_f64_data

Function tfe_tensor_f64_data 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn tfe_tensor_f64_data( tensor: *const TfeTensorF64, status: *mut tfe_status_t, ) -> *const f64
Return a pointer to the tensor’s raw data buffer.

The pointer is valid until tfe_tensor_f64_release is called on the tensor. Returns null if tensor is null.

Safety

  • tensor must be a valid tensor pointer or null.
  • status must be a valid, non-null pointer.
  • The returned pointer must not be used after tfe_tensor_f64_release(tensor).