tfe_tensor_f64_len

Function tfe_tensor_f64_len 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn tfe_tensor_f64_len( tensor: *const TfeTensorF64, status: *mut tfe_status_t, ) -> usize
Return the total number of elements in the tensor.

Returns 0 if tensor is null (and sets status to TFE_INVALID_ARGUMENT).

Safety

  • tensor must be a valid tensor pointer or null.
  • status must be a valid, non-null pointer.